const dataset = [
  { apples: 5, oranges: 10, grapes: 22 },
  { apples: 4, oranges: 12, grapes: 28 },
  { apples: 2, oranges: 19, grapes: 32 },
  { apples: 7, oranges: 23, grapes: 35 },
  { apples: 23, oranges: 17, grapes: 43 },
];

const stack = d3
  .stack()
  .keys(['apples', 'oranges', 'grapes'])
	.order(d3.stackOrderDescending);

const series = stack(dataset);

const w = window.innerWidth;
const h = window.innerHeight;
const margin = { top: 20, right: 20, bottom: 20, left: 20 };

const colors = d3.scaleOrdinal(d3.schemeCategory10);

const xScale = d3
  .scaleBand()
  .domain(d3.range(dataset.length))
  .range([margin.left, w - margin.right])
  .paddingInner(0.05);

const yScale = d3
  .scaleLinear()
  .domain([
    0,
    d3.max(dataset, (d) => d.apples + d.oranges + d.grapes),
  ])
  .range([h - margin.top, margin.bottom]);

const svg = d3
  .select('body')
  .append('svg')
  .attr('width', w)
  .attr('height', h);

const groups = svg
  .selectAll('g')
  .data(series)
  .join('g')
  .style('fill', (d, i) => colors(i));

const rects = groups
  .selectAll('rect')
  .data((d) => d)
  .join('rect')
  .attr('x', (d, i) => xScale(i))
  .attr('y', (d) => yScale(d[1]))
  .attr('height', (d) => yScale(d[0]) - yScale(d[1]))
  .attr('width', xScale.bandwidth());
